==> libreoffice-7.0.6.2.tar.xz: libreoffice-7.0.6.2/idlc/source/aststack.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <rtl/alloc.h>
#include <aststack.hxx>
#include <astscope.hxx>

AstStack::AstStack()
{
}

AstStack::~AstStack()
{
    for (AstScope* p : m_stack)
        delete p;
}


AstScope* AstStack::top()
{
    if (m_stack.empty())
        return nullptr;
    return m_stack.back();
}

AstScope* AstStack::bottom()
{
    if (m_stack.empty())
        return nullptr;
    return m_stack.front();
}

AstScope* AstStack::nextToTop()
{
    if (m_stack.size() < 2)
        return nullptr;

    return m_stack[m_stack.size() - 2];
}

AstScope* AstStack::topNonNull()
{
    for (sal_uInt32 i = m_stack.size(); i > 0; i--)
    {
        if ( m_stack[i - 1] )
            return m_stack[i - 1];
    }
    return nullptr;
}

AstStack* AstStack::push(AstScope* pScope)
{
    m_stack.push_back(pScope);
    return this;
}

void AstStack::pop()
{
    if (m_stack.empty())
        return;
    m_stack.pop_back();
}

void AstStack::clear()
{
   m_stack.clear();
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.4.7.orig.tar.xz: libreoffice-7.4.7.2/idlc/source/aststack.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <rtl/alloc.h>
#include <aststack.hxx>
#include <astscope.hxx>

AstStack::AstStack() {}

AstStack::~AstStack()
{
    for (AstScope* p : m_stack)
        delete p;
}

AstScope* AstStack::top()
{
    if (m_stack.empty())
        return nullptr;
    return m_stack.back();
}

AstScope* AstStack::bottom()
{
    if (m_stack.empty())
        return nullptr;
    return m_stack.front();
}

AstScope* AstStack::nextToTop()
{
    if (m_stack.size() < 2)
        return nullptr;

    return m_stack[m_stack.size() - 2];
}

AstScope* AstStack::topNonNull()
{
    for (sal_uInt32 i = m_stack.size(); i > 0; i--)
    {
        if (m_stack[i - 1])
            return m_stack[i - 1];
    }
    return nullptr;
}

AstStack* AstStack::push(AstScope* pScope)
{
    m_stack.push_back(pScope);
    return this;
}

void AstStack::pop()
{
    if (m_stack.empty())
        return;
    m_stack.pop_back();
}

void AstStack::clear() { m_stack.clear(); }

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
